from setuptools import setup

setup(name='stats_distributions_package',
      version='0.2',
      description='Gaussian distributions',
      packages=['stats_distributions_package'],
      zip_safe=False)
